@@ -99,7 +99,7 @@ class BspParser(object):
 		"bsp_path": "$bsp_path",
 		"project_name": "$project_name",
 		"output_project_path": "$output_project_path",
-		"from_example": "$from_example",
+		"from_example": $from_example,
 		"example_name": "$example_name",
 		"project_type": "$project_type",
 		"action": "create_project"
@@ -112,7 +112,7 @@ class BspParser(object):
                                              project_type=str(project['project_type']),
                                              project_name=str(project_name),
                                              output_project_path=str(output_project_path),
-                                             from_example=False,
+                                             from_example="false",
                                              example_name="")
             dict_lit = json.loads(wstrs)
             bsp_test_dict[project_name] = dict_lit
@@ -126,7 +126,7 @@ class BspParser(object):
                                              project_type=str(project['project_type']),
                                              project_name=str(project_name),
                                              output_project_path=str(output_project_path),
-                                             from_example=True,
+                                             from_example="true",
                                              example_name=project["project_name"])
             dict_lit = json.loads(wstrs)
             bsp_test_dict[project_name] = dict_lit
